.. _tweakreg:

*************************
TWEAKREG: Image Alignment
*************************
Combining images using ``AstroDrizzle`` requires that the WCS information in
the headers of each input image align to within sub-pixel accuracy.
The ``TweakReg`` task allows the user to align sets of images to each
other and/or to and external astrometric reference frame or image.

.. moduleauthor:: Warren Hack, Mihai Cara <help@stsci.edu>

.. automodule:: drizzlepac.tweakreg

.. autofunction:: TweakReg

.. autofunction:: help

